Learn R Programming

tourrGui (version 0.2)

gui_tour: Tour GUI...

Description

Tour GUI Displays all types of Tour GUI in different tabs

Usage

gui_tour(data = flea, ...)

Arguments

data
matrix, or data frame containing numeric columns, defaults to flea dataset
...
other arguments passed on to animate and display_xy

Details

Combines all of the tour gui's into one, putting a separate tab for each.

Examples

Run this code
gui_tour(flea)

Run the code above in your browser using DataLab